.. libyamlconf documentation master file, created by
   sphinx-quickstart on Mon Mar  3 08:28:31 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

libyamlconf documentation
=========================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage
   yaml
   verify
   indices

.. automodule:: libyamlconf
    :members:
